weaviate.rbac
===============

.. automodule:: weaviate.rbac
   :members:
   :undoc-members:
   :show-inheritance:

Submodules
----------

weaviate.rbac.models module
-----------------------------

.. automodule:: weaviate.rbac.models
   :members:
   :undoc-members:
   :show-inheritance:

weaviate.rbac.roles module
-----------------------------

.. automodule:: weaviate.rbac.roles
   :members:
   :undoc-members:
   :show-inheritance:
